| Istep_Z | R Documentation |
Impute missing data in Z by maximizing the likelihood given fixed parameters
Istep_Z(Z, p, mu, sigma, index, lucid_model)
Z |
Matrix or list of matrices for omics data |
p |
Probability matrix/vector or list for parallel model |
mu |
Mean matrix or list of matrices |
sigma |
Covariance array or list of arrays |
index |
Missing value indicators |
lucid_model |
Model type |
Imputed dataset
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.