fill_data: Impute missing data by optimizing the likelihood function

View source: R/missing.R

fill_dataR Documentation

Impute missing data by optimizing the likelihood function

Description

Impute missing data by optimizing the likelihood function

Usage

fill_data(obs, mu, sigma, p, index, lucid_model)

Arguments

obs

a vector of length M

mu

a matrix of size K x M for parallel model, M x K for early model

sigma

a matrix of size M x M x K

p

a vector of length K

index

a vector of length M, indicating whether a value is missing

lucid_model

Specifying LUCID model

Value

an observation with updated imputed values


LUCIDus documentation built on March 11, 2026, 9:06 a.m.

Related to fill_data in LUCIDus...