print.sumlucid_parallel: Print the output of LUCID in a nicer table

View source: R/summary.R

print.sumlucid_parallelR Documentation

Print the output of LUCID in a nicer table

Description

Print the output of LUCID in a nicer table

Usage

## S3 method for class 'sumlucid_parallel'
print(x, ...)

Arguments

x

An object returned by summary

...

Other parameters to be passed to print.sumlucid_parallel

Value

x, invisibly. Called for its side effect: printing a structured parallel-model summary – per-layer missing-data profile, overall and per-layer feature-selection overview, model fit statistics, regularization settings, and parameter estimates for sections (1) Y, (2) Z and (3) E. If boot.se was provided to summary(), bootstrap confidence limits are shown for each of those three sections.


LUCIDus documentation built on Sept. 3, 2026, 1:06 a.m.