sim_data: A simulated dataset for LUCID

sim_dataR Documentation

A simulated dataset for LUCID

Description

An example dataset used to illustrate the LUCID model, simulated under two latent clusters. The exposures are associated with the latent cluster, which in turn affects PFAS concentration and liver injury in children; the clusters are also characterised by differential metabolite levels. Because the generating cluster membership is retained in X, the data can be used to check recovered clusters against the truth, up to the arbitrary labelling of clusters.

Usage

sim_data

Format

A list of 6 elements, each with 2000 observations:

G

A 2000 by 10 matrix of exposures.

Z

A 2000 by 10 matrix of metabolites.

Y_normal

A 2000 by 1 matrix; continuous outcome, PFAS concentration in children.

Y_binary

A 2000 by 1 matrix; binary outcome, liver injury status, coded 0 and 1.

Covariate

A 2000 by 2 matrix of continuous covariates, usable as either CoG or CoY.

X

An integer vector of length 2000 giving the latent cluster each observation was generated from.


LUCIDus documentation built on Sept. 3, 2026, 1:06 a.m.