| fill_data | R Documentation |
Impute missing data by optimizing the likelihood function
fill_data(obs, mu, sigma, p, index, lucid_model)
obs |
a vector of length M |
mu |
a matrix of size K x M for parallel model, M x K for early model |
sigma |
a matrix of size M x M x K |
p |
a vector of length K |
index |
a vector of length M, indicating whether a value is missing |
lucid_model |
Specifying LUCID model |
an observation with updated imputed values
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.