- G
Exposures, a numeric vector, matrix, or data frame. Categorical variable
should be transformed into dummy variables. If a matrix or data frame, rows
represent observations and columns correspond to variables.
- Z
Omics data. If "early", an N by M matrix. If "parallel", a list,
each element i is a matrix with N rows and P_i features. If "serial", a list,
each element i is either a matrix with N rows and p_i features, or a list with
two or more matrices with N rows.
- Y
Outcome, a numeric vector. Categorical variable is not allowed. Binary
outcome should be coded as 0 and 1.
- CoG
Optional, covariates to be adjusted for estimating the latent cluster.
A numeric vector, matrix or data frame. Categorical variable should be transformed
into dummy variables.
- CoY
Optional, covariates to be adjusted for estimating the association
between latent cluster and the outcome. A numeric vector, matrix or data frame.
Categorical variable should be transformed into dummy variables.
- family
Distribution of outcome. For continuous outcome, use "normal";
for binary outcome, use "binary". Default is "normal".
- K
Number of latent clusters to be tuned. For lucid_model = "early", number of latent clusters (should be greater or equal than 2).
Either an integer or a vector of integer. If K is a vector, model selection
on K is performed. For lucid_model = "parallel",a list with vectors of integers or just integers, same length as Z,
if the element itself is a vector, model selection on K is performed;
For lucid_model = "serial", a list, each element is either an integer or an list of integers, same length as Z,
if the smallest element (integer) itself is a vector, model selection on K is performed
- lucid_model
Specifying LUCID model, "early" for early integration, "parallel" for lucid in parallel,
"serial" for lucid in serial
- Rho_G
A scalar or a vector. This parameter is the LASSO penalty to regularize
exposure coefficients in the G-to-X model; CoG covariates are not
penalized. If it is a vector, lucid will call tune_lucid to
conduct model selection and variable selection. User can try penalties from 0
to 1. Penalty tuning is supported for "early" and "parallel". For "serial",
only scalar penalty inputs are supported.
- Rho_Z_Mu
A scalar or a vector. This parameter is the LASSO penalty to
regularize cluster-specific means for omics data (Z). If it is a vector,
lucid will call tune_lucid to conduct model selection and
variable selection. User can try penalties from 1 to 100. Penalty tuning is
supported for "early" and "parallel". For "serial", only scalar penalty
inputs are supported.
- Rho_Z_Cov
A scalar or a vector. This parameter is the graphical LASSO
penalty to estimate sparse cluster-specific variance-covariance matrices for omics
data (Z). If it is a vector, lucid will call tune_lucid to conduct
model selection and variable selection. User can try penalties from 0 to 1.
Penalty tuning is supported for "early" and "parallel". For "serial", only
scalar penalty inputs are supported.
- verbose_tune
A flag to print details of tuning process.
- ...
Other parameters passed to estimate_lucid