| print.sumlucid_early | R Documentation |
Print the output of LUCID in a nicer table
## S3 method for class 'sumlucid_early'
print(x, ...)
x |
An object returned by |
... |
Other parameters to be passed to |
Prints a structured model summary, including model specification, missing-data
profile, feature-selection overview, model fit statistics, regularization settings,
and detailed parameter estimates. If boot.se is provided in summary(),
bootstrap CI tables are shown for sections (1) Y, (2) Z, and (3) E.
# use simulated data
G <- sim_data$G[1:300, , drop = FALSE]
Z <- sim_data$Z[1:300, , drop = FALSE]
Y_normal <- sim_data$Y_normal[1:300]
# fit lucid model
fit1 <- estimate_lucid(G = G, Z = Z, Y = Y_normal, lucid_model = "early", family = "normal", K = 2,
seed = 1008)
# conduct bootstrap resampling
boot1 <- suppressWarnings(
boot_lucid(G = G, Z = Z, Y = Y_normal, lucid_model = "early", model = fit1, R = 5)
)
# print the summary of the lucid model in a table
temp <- summary(fit1)
print(temp)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.