Learn R Programming

LUCIDus (version 3.2.1)

print.sumlucid_early: Print the output of LUCID in a nicer table

Description

Print the output of LUCID in a nicer table

Usage

# S3 method for sumlucid_early
print(x, ...)

Value

Prints a structured model summary, including model specification, missing-data profile, feature-selection overview, model fit statistics, regularization settings, and detailed parameter estimates. If boot.se is provided in summary(), bootstrap CI tables are shown for sections (1) Y, (2) Z, and (3) E.

Arguments

x

An object returned by summary

...

Other parameters to be passed to print.sumlucid_serial

Examples

Run this code
# \donttest{
# use simulated data (a small subset keeps the example quick)
G <- sim_data$G[1:150, , drop = FALSE]
Z <- sim_data$Z[1:150, , drop = FALSE]
Y_normal <- sim_data$Y_normal[1:150]

# fit lucid model
fit1 <- estimate_lucid(G = G, Z = Z, Y = Y_normal, lucid_model = "early", family = "normal", K = 2,
seed = 1008, max_itr = 20, max_tot.itr = 50)

# conduct bootstrap resampling
boot1 <- suppressWarnings(
  boot_lucid(G = G, Z = Z, Y = Y_normal, lucid_model = "early", model = fit1, R = 2)
)

# print the summary of the lucid model in a table
temp <- summary(fit1)
print(temp)
# }

Run the code above in your browser using DataLab