| sim_data | R Documentation |
An example dataset used to illustrate the LUCID model, simulated
under two latent clusters. The exposures are associated with the latent
cluster, which in turn affects PFAS concentration and liver injury in
children; the clusters are also characterised by differential metabolite
levels. Because the generating cluster membership is retained in X, the
data can be used to check recovered clusters against the truth, up to the
arbitrary labelling of clusters.
sim_data
A list of 6 elements, each with 2000 observations:
A 2000 by 10 matrix of exposures.
A 2000 by 10 matrix of metabolites.
A 2000 by 1 matrix; continuous outcome, PFAS concentration in children.
A 2000 by 1 matrix; binary outcome, liver injury status, coded 0 and 1.
A 2000 by 2 matrix of continuous covariates, usable as
either CoG or CoY.
An integer vector of length 2000 giving the latent cluster each observation was generated from.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.